@@ -7,7 +7,7 @@
 #     modify it under the same terms as Perl itself.
 
 package SNMP;
-$VERSION = '1.8.1';   # current release version number
+$VERSION = '1.8.2';   # current release version number
 
 require Exporter;
 require DynaLoader;
@@ -201,7 +201,8 @@ sub mapEnum {
       $tag = $var;
       $val = shift;
   }
-  my $res = SNMP::_map_enum($tag, $val, $val =~ /^\d+$/);
+  my $iflag = $val =~ /^\d+$/;
+  my $res = SNMP::_map_enum($tag, $val, $iflag);
   if ($update and defined $res) { $var->[$SNMP::Varbind::val_f] = $res; }
   return($res);
 }
@@ -594,7 +595,7 @@ sub new {
 
    return undef unless $this->{SessPtr};
 
-   SNMP::initMib() if $SNMP::auto_init_mib; # ensures that *some* mib is loaded
+   SNMP::initMib($SNMP::auto_init_mib); # ensures that *some* mib is loaded
 
    $this->{UseLongNames} ||= $SNMP::use_long_names;
    $this->{UseSprintValue} ||= $SNMP::use_sprint_value;
